@@ -5,7 +5,7 @@
   Copyright (C) 2002-2005 Nasca Octavian Paul
   Author: Nasca Octavian Paul
 
-  Modified for rakarrack by Josep Andreu
+  Modified for rakarrack by Josep Andreu & Ryan Billing
 
 
   This program is free software; you can redistribute it and/or modify
@@ -25,9 +25,7 @@
 
 #ifndef EFFECT_LFO_H
 #define EFFECT_LFO_H
-
 #include "global.h"
-#define REALTYPE float
 
 
 class EffectLFO
@@ -35,21 +33,36 @@ class EffectLFO
 public:
   EffectLFO ();
   ~EffectLFO ();
-  void effectlfoout (REALTYPE * outl, REALTYPE * outr);
+  void effectlfoout (float * outl, float * outr);
   void updateparams ();
-  unsigned char Pfreq;
-  unsigned char Prandomness;
-  unsigned char PLFOtype;
-  unsigned char Pstereo;	//"64"=0
+  int Pfreq;
+  int Prandomness;
+  int PLFOtype;
+  int Pstereo;	//"64"=0
 private:
-    REALTYPE getlfoshape (REALTYPE x);
+    float getlfoshape (float x);
 
-  REALTYPE xl, xr;
-  REALTYPE incx;
-  REALTYPE ampl1, ampl2, ampr1, ampr2;	//necesar pentru "randomness"
-  REALTYPE lfointensity;
-  REALTYPE lfornd;
-  char lfotype;
+  float xl, xr;
+  float incx;
+  float ampl1, ampl2, ampr1, ampr2;	//necesar pentru "randomness"
+  float lfointensity;
+  float lfornd;
+  int lfotype;
+  
+  //Lorenz Fractal parameters
+   float x0,y0,z0,x1,y1,z1,radius;
+   float h;
+   float a;
+   float b;
+   float c;
+   float scale;
+   float iperiod; 
+   float ratediv;
+   
+   //Sample/Hold
+   int holdflag;  //toggle left/right channel changes
+   float tca, tcb, maxrate;
+   float rreg, lreg, xlreg,xrreg, oldrreg, oldlreg;
 };
 
 
