@@ -38,15 +38,16 @@ class Filter
 public:
   Filter (FilterParams * pars);
   ~Filter ();
-  void filterout (REALTYPE * smp);
-  void setfreq (REALTYPE frequency);
-  void setfreq_and_q (REALTYPE frequency, REALTYPE q_);
-  void setq (REALTYPE q_);
+  void filterout (float * smp);
+  void setfreq (float frequency);
+  void setfreq_and_q (float frequency, float q_);
+  void setq (float q_);
+  float getrealfreq (float freqpitch);
 
-  REALTYPE getrealfreq (REALTYPE freqpitch);
 private:
+   unsigned char category;
+
     Filter_ * filter;
-  unsigned char category;
 };
 
 
