@@ -16,43 +16,34 @@
 #include <math.h>
 #include <stdlib.h>
 
-#define REALTYPE float
-
-#define D_NOTE          1.059463094359
-#define LOG_D_NOTE      0.057762265047
-#define D_NOTE_SQRT     1.029302236643
-#define LOG_2           0.693147180559
-#define M_PI 3.14159265358979323846
-#define MAX_PEAKS 8
-
 
 class Tuner
 {
 public:
-  Tuner (REALTYPE * efxoutl_, REALTYPE * efxoutr_);
+  Tuner ();
   ~Tuner ();
+  void schmittFloat (int nframes, float *indatal, float *indatar);
 
-  REALTYPE *efxoutl;
-  REALTYPE *efxoutr;
-  signed short int *schmittBuffer;
-  signed short int *schmittPointer;
-  const char **notes;
   int note;
   int preparada;
   int note_actual;
-  float nfreq, afreq, freq;
   int cents;
-  void schmittFloat (int nframes, float *indatal, float *indatar);
+  signed short int *schmittBuffer;
+  signed short int *schmittPointer;
+  const char **notes;
+  float nfreq, afreq, freq;
+  float *efxoutl;
+  float *efxoutr;
+
 private:
 
-
-  float freqs[12];
-  float lfreqs[12];
-  int blockSize;
   void displayFrequency (float freq);
   void schmittInit (int size);
   void schmittS16LE (int nframes, signed short int *indata);
   void schmittFree ();
+
+  int blockSize;
+
 };
 
 #endif /*TUNER_H_ */
