@@ -2,8 +2,8 @@
   rakarrak - a guitar efects software
 
   jack.h  -  some jack definitions
-  Copyright (C) 2008 Daniel Vidal & Josep Andreu
-  Author: Daniel Vidal & Josep Andreu
+  Copyright (C) 2008-2010 Josep Andreu
+  Author: Josep Andreu
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of version 2 of the GNU General Public License
@@ -27,7 +27,8 @@
 
 int JACKstart (RKR * rkr_, jack_client_t * jackclient);
 void JACKfinish ();
+int timebase(jack_transport_state_t state, jack_position_t *pos, void *arg);
+void actualiza_tap(double val);
 void jackshutdown (void *arg);
 
-
 #endif
